﻿import util.*;

/**
 * Creates a sky full of stars, and listens for Randomizer
 * events to create random shooting stars.
 */
class nightsky.NightSky implements RandomizerListener {
  // The MovieClip in which to create the sky.
  private var target:MovieClip;
  // The sky movie clip.
  private var sky_mc:MovieClip;
  // The depth, in target, at which to create the sky. Defauts to 0.
  private var skyDepth:Number = 0;
  // The depth, in sky_mc, at which to create shooting stars. Defaults to 0.
  private var starDepth:Number = 0;
 
  /**
   * Constructor
   */
  public function NightSky (target:MovieClip, skyDepth:Number, starDepth:Number) {
    this.target = target;
    this.skyDepth = skyDepth;
    this.starDepth = starDepth;
    makeSkyBG();
  }

  /**
   * Responds to random events from a Randomizer object.
   * Creates a shooting star in the sky.
   * 
   * @param   e   An object that describes the event.
   */
  public function onRandomAction (e:RandomizerEvent):Void {
    trace("New shooting star! Time since last star: " + e.getTimeSinceLast());
    makeShootingStar();
  }

  /**
   * Creates a sky graphic by attaching a movie clip with the
   * linkage identifier of "skybg".
   */
  private function makeSkyBG ():Void {
    sky_mc = target.attachMovie("skybg", "skybg", skyDepth);
  }
  
  /**
   * Creates a shooting star by attaching a movie clip with the
   * linkage identifier of "shootingstar".
   */
  private function makeShootingStar ():Void {
    // Create the shooting star in the sky movie clip.
    sky_mc.attachMovie("shootingstar", "shootingstar" + starDepth, starDepth);
    // Randomly position the shooting star.
    sky_mc["shootingstar" + starDepth]._x = Math.floor(Math.random() * target.skybg._width);
    sky_mc["shootingstar" + starDepth]._y = Math.floor(Math.random() * target.skybg._height);
    // Put the next shooting star on a higher depth.
    starDepth++;
  }
}